==> bulma-tooltip-1.0.3.jar: META-INF/resources/webjars/bulma-tooltip/1.0.3/CHANGELOG.md <==
<a name="1.0.3"></a>
## [1.0.3](https://github.com/Wikiki/bulma-tooltip/compare/1.0.2...1.0.3) (2018-02-13)


### Bug Fixes

* **loading:** Better code ([5fc73fb](https://github.com/Wikiki/bulma-tooltip/commit/5fc73fb))



<a name="1.0.2"></a>
## [1.0.2](https://github.com/Wikiki/bulma-tooltip/compare/1.0.1...1.0.2) (2018-02-13)


### Bug Fixes

* **loading:** Keep loading style ([a910196](https://github.com/Wikiki/bulma-tooltip/commit/a910196))



<a name="1.0.1"></a>
## [1.0.1](https://github.com/Wikiki/bulma-tooltip/compare/1.0.0...1.0.1) (2018-02-11)


### Bug Fixes

* **gulp:** Remove Bulma’s important from dist’sass ([e47cc11](https://github.com/Wikiki/bulma-tooltip/commit/e47cc11))



<a name="1.0.0"></a>
# [1.0.0](https://github.com/Wikiki/bulma-tooltip/compare/0.1.7...1.0.0) (2018-02-10)



<a name="0.1.7"></a>
## [0.1.7](https://github.com/Wikiki/bulma-tooltip/compare/0.1.6...0.1.7) (2018-02-10)



<a name="0.1.6"></a>
## [0.1.6](https://github.com/Wikiki/bulma-tooltip/compare/0.1.5...0.1.6) (2018-02-10)


### Bug Fixes

* **gulp:** Use UMD modules style ([364d53c](https://github.com/Wikiki/bulma-tooltip/commit/364d53c))



<a name="0.1.5"></a>
## [0.1.5](https://github.com/Wikiki/bulma-tooltip/compare/0.1.4...0.1.5) (2018-02-10)


### Bug Fixes

* **gulp:** Clean whole dist folder ([e403d11](https://github.com/Wikiki/bulma-tooltip/commit/e403d11))
* **gulp:** Correct dist filenames ([ece4bd4](https://github.com/Wikiki/bulma-tooltip/commit/ece4bd4))
* **package.json:** Main file path correction ([8b52ee1](https://github.com/Wikiki/bulma-tooltip/commit/8b52ee1))
* **package.json:** Main file path correction ([d3feb49](https://github.com/Wikiki/bulma-tooltip/commit/d3feb49))



<a name="0.1.4"></a>
## [0.1.4](https://github.com/Wikiki/bulma-tooltip/compare/0.1.1...0.1.4) (2018-02-09)


### Bug Fixes

* **bower:** Add missing version ([ef90484](https://github.com/Wikiki/bulma-tooltip/commit/ef90484))


### Features

* **gulp:** Add release task ([6baf98c](https://github.com/Wikiki/bulma-tooltip/commit/6baf98c))



# Change Log

## [Unreleased](https://github.com/wikiki/bulma-tooltip/tree/HEAD)

[Full Changelog](https://github.com/wikiki/bulma-tooltip/compare/0.1.1...HEAD)

**Implemented enhancements:**

- Adding .is-tooltip-active [\#11](https://github.com/Wikiki/bulma-tooltip/issues/11)

**Fixed bugs:**

- Import problem [\#5](https://github.com/Wikiki/bulma-tooltip/issues/5)

**Closed issues:**

- tooltip.sass should imports initial variables [\#9](https://github.com/Wikiki/bulma-tooltip/issues/9)
- Right out of the gate, tooltip flickers [\#8](https://github.com/Wikiki/bulma-tooltip/issues/8)
- defect link on readme.md [\#7](https://github.com/Wikiki/bulma-tooltip/issues/7)
- bower? [\#6](https://github.com/Wikiki/bulma-tooltip/issues/6)

**Merged pull requests:**

- Fix \#11: Keep tooltip open with .is-tooltip-active [\#12](https://github.com/Wikiki/bulma-tooltip/pull/12) ([alfonsogarciacaro](https://github.com/alfonsogarciacaro))

## [0.1.1](https://github.com/wikiki/bulma-tooltip/tree/0.1.1) (2017-11-30)
**Closed issues:**

- Tooltip wrap around [\#4](https://github.com/Wikiki/bulma-tooltip/issues/4)
- Error compiling tooltip.sass to .css [\#3](https://github.com/Wikiki/bulma-tooltip/issues/3)
- Missing LICENSE file [\#2](https://github.com/Wikiki/bulma-tooltip/issues/2)
- Compatibility [\#1](https://github.com/Wikiki/bulma-tooltip/issues/1)



\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> bulma-tooltip-3.0.2.jar: META-INF/resources/webjars/bulma-tooltip/3.0.2/CHANGELOG.md <==
<a name="3.0.0"></a>
## [3.0.0](https://github.com/Wikiki/bulma-tooltip/compare/1.0.5...3.0.0) (2019-10-06)

### Breaking changes
**Careful** You must now use <code>has-tooltip-*</code> classes.

### Bug Fixes
- Lots of display bug fixes

<a name="1.0.5"></a>
## [1.0.5](https://github.com/Wikiki/bulma-tooltip/compare/1.0.4...1.0.5) (2018-05-12)


### Bug Fixes

* [#20](https://github.com/Wikiki/bulma-tooltip/issues/20) Multiline problem with few text ([eb00d1b](https://github.com/Wikiki/bulma-tooltip/commit/eb00d1b))



<a name="1.0.4"></a>
## [1.0.4](https://github.com/Wikiki/bulma-tooltip/compare/1.0.3...1.0.4) (2018-03-29)



<a name="1.0.3"></a>
## [1.0.3](https://github.com/Wikiki/bulma-tooltip/compare/1.0.2...1.0.3) (2018-02-13)


### Bug Fixes

* **loading:** Better code ([5fc73fb](https://github.com/Wikiki/bulma-tooltip/commit/5fc73fb))



<a name="1.0.2"></a>
## [1.0.2](https://github.com/Wikiki/bulma-tooltip/compare/1.0.1...1.0.2) (2018-02-13)


### Bug Fixes

* **loading:** Keep loading style ([a910196](https://github.com/Wikiki/bulma-tooltip/commit/a910196))



<a name="1.0.1"></a>
## [1.0.1](https://github.com/Wikiki/bulma-tooltip/compare/1.0.0...1.0.1) (2018-02-11)


### Bug Fixes

* **gulp:** Remove Bulma’s important from dist’sass ([e47cc11](https://github.com/Wikiki/bulma-tooltip/commit/e47cc11))



<a name="1.0.0"></a>
# [1.0.0](https://github.com/Wikiki/bulma-tooltip/compare/0.1.7...1.0.0) (2018-02-10)



<a name="0.1.7"></a>
## [0.1.7](https://github.com/Wikiki/bulma-tooltip/compare/0.1.6...0.1.7) (2018-02-10)



<a name="0.1.6"></a>
## [0.1.6](https://github.com/Wikiki/bulma-tooltip/compare/0.1.5...0.1.6) (2018-02-10)


### Bug Fixes

* **gulp:** Use UMD modules style ([364d53c](https://github.com/Wikiki/bulma-tooltip/commit/364d53c))



<a name="0.1.5"></a>
## [0.1.5](https://github.com/Wikiki/bulma-tooltip/compare/0.1.4...0.1.5) (2018-02-10)


### Bug Fixes

* **gulp:** Clean whole dist folder ([e403d11](https://github.com/Wikiki/bulma-tooltip/commit/e403d11))
* **gulp:** Correct dist filenames ([ece4bd4](https://github.com/Wikiki/bulma-tooltip/commit/ece4bd4))
* **package.json:** Main file path correction ([8b52ee1](https://github.com/Wikiki/bulma-tooltip/commit/8b52ee1))
* **package.json:** Main file path correction ([d3feb49](https://github.com/Wikiki/bulma-tooltip/commit/d3feb49))



<a name="0.1.4"></a>
## [0.1.4](https://github.com/Wikiki/bulma-tooltip/compare/0.1.1...0.1.4) (2018-02-09)


### Bug Fixes

* **bower:** Add missing version ([ef90484](https://github.com/Wikiki/bulma-tooltip/commit/ef90484))


### Features

* **gulp:** Add release task ([6baf98c](https://github.com/Wikiki/bulma-tooltip/commit/6baf98c))



# Change Log

## [Unreleased](https://github.com/wikiki/bulma-tooltip/tree/HEAD)

[Full Changelog](https://github.com/wikiki/bulma-tooltip/compare/0.1.1...HEAD)

**Implemented enhancements:**

- Adding .is-tooltip-active [\#11](https://github.com/Wikiki/bulma-tooltip/issues/11)

**Fixed bugs:**

- Import problem [\#5](https://github.com/Wikiki/bulma-tooltip/issues/5)

**Closed issues:**

- tooltip.sass should imports initial variables [\#9](https://github.com/Wikiki/bulma-tooltip/issues/9)
- Right out of the gate, tooltip flickers [\#8](https://github.com/Wikiki/bulma-tooltip/issues/8)
- defect link on readme.md [\#7](https://github.com/Wikiki/bulma-tooltip/issues/7)
- bower? [\#6](https://github.com/Wikiki/bulma-tooltip/issues/6)

**Merged pull requests:**

- Fix \#11: Keep tooltip open with .is-tooltip-active [\#12](https://github.com/Wikiki/bulma-tooltip/pull/12) ([alfonsogarciacaro](https://github.com/alfonsogarciacaro))

## [0.1.1](https://github.com/wikiki/bulma-tooltip/tree/0.1.1) (2017-11-30)
**Closed issues:**

- Tooltip wrap around [\#4](https://github.com/Wikiki/bulma-tooltip/issues/4)
- Error compiling tooltip.sass to .css [\#3](https://github.com/Wikiki/bulma-tooltip/issues/3)
- Missing LICENSE file [\#2](https://github.com/Wikiki/bulma-tooltip/issues/2)
- Compatibility [\#1](https://github.com/Wikiki/bulma-tooltip/issues/1)



\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*
